Restart a simulation
====================

Let's run a small simulation with this script:

.. literalinclude:: simul_ns2d.py

To restart this simulation and continue the time_stepping, one can use a script
like this:

.. literalinclude:: simul_ns2d_restart.py

Note that there is also a command-line tool (``fluidsim-restart``) to restart
simulation as presented `here <../ipynb/restart_modif_resol.html>`_.
